An ICC shows the probability of getting an item correct as a function of ability. Each item gets one curve. Harder items have curves shifted to the right.
Usage
plot_icc(object, items = NULL, theta_range = c(-4, 4), ci = TRUE, ...)An ICC shows the probability of getting an item correct as a function of ability. Each item gets one curve. Harder items have curves shifted to the right.
plot_icc(object, items = NULL, theta_range = c(-4, 4), ci = TRUE, ...)